/* 
 * AndSys 0.3.e.21 Copyright (C) 2012, 2013 Giulio Orru'
 * 
 * Licensed under the MIT license:
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.andsys;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Environment;
import android.os.StatFs;
import android.util.DisplayMetrics;

import java.io.File;

public class Device {
    
    public static final String ANDROID_VERSION = android.os.Build.VERSION.RELEASE;
    public static final int ANDROID_API = android.os.Build.VERSION.SDK_INT;
    public static final String MODEL_NAME = android.os.Build.MODEL;
    

    /*
     * Memory: PHONE STORAGE
     */

    public static long memPhoneStorageFree() {
        File path = Environment.getDataDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = stat.getAvailableBlocks() * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    public static long memPhoneStorageUsed() {
        File path = Environment.getDataDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = (stat.getBlockCount() - stat.getAvailableBlocks()) * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    public static long memPhoneStorageTotal() {
        File path = Environment.getDataDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = stat.getBlockCount() * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    /*
     * Memory: SD CARD
     */

    public static long memSdCardFree() {

        File path = Environment.getExternalStorageDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = stat.getAvailableBlocks() * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    public static long memSdCardUsed() {

        File path = Environment.getExternalStorageDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = (stat.getBlockCount() - stat.getAvailableBlocks()) * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    public static long memSdCardTotal() {

        File path = Environment.getExternalStorageDirectory();
        StatFs stat = new StatFs(path.getPath());
        // return value is in bytes
        long memory = stat.getBlockCount() * stat.getBlockSize();

        return (memory < 0) ? 0 : memory;
    }

    
    /*
     * Screen & Display
     */

    public static int displayHeightPixels(Activity activity) {
        DisplayMetrics metrics = new DisplayMetrics();
        activity.getWindowManager().getDefaultDisplay().getMetrics(metrics);

        return metrics.heightPixels;
    }

    public static int displayWidthPixels(Activity activity) {
        DisplayMetrics metrics = new DisplayMetrics();
        activity.getWindowManager().getDefaultDisplay().getMetrics(metrics);

        return metrics.widthPixels;
    }

    public static String screenDensityClass(Activity activity) {
        DisplayMetrics metrics = new DisplayMetrics();
        activity.getWindowManager().getDefaultDisplay().getMetrics(metrics);

        if (metrics.densityDpi == 0) {

            return "unknown";
        } else if (metrics.densityDpi <= DisplayMetrics.DENSITY_LOW) {

            return "low (ldpi)";
        } else if (metrics.densityDpi <= DisplayMetrics.DENSITY_MEDIUM) {

            return "medium (mdpi)";
        } else if (metrics.densityDpi <= DisplayMetrics.DENSITY_HIGH) {

            return "high (hdpi)";
        } else {
            // (metrics.densityDpi > DisplayMetrics.DENSITY_HIGH)

            return "extra high (xhdpi)";
        }
    }
    
    public static String screenSizeClass(Activity activity) {
        /*
         * http://developer.android.com/guide/practices/screens_support.html
         * 
         * - xlarge screens are at least 960dp x 720dp
         * 
         * - large screens are at least 640dp x 480dp
         * 
         * - normal screens are at least 470dp x 320dp
         * 
         * - small screens are at least 426dp x 320dp
         */

        int screenlayout = activity.getResources().getConfiguration().screenLayout
                & Configuration.SCREENLAYOUT_SIZE_MASK;

        if (screenlayout <= Configuration.SCREENLAYOUT_SIZE_UNDEFINED) {

            return "UNDEFINED";
        } else if (screenlayout <= Configuration.SCREENLAYOUT_SIZE_SMALL) {

            return "SMALL";
        } else if (screenlayout <= Configuration.SCREENLAYOUT_SIZE_NORMAL) {

            return "NORMAL";
        } else if (screenlayout <= Configuration.SCREENLAYOUT_SIZE_LARGE) {

            return "LARGE";
        } else {
            // (screenlayout > Configuration.SCREENLAYOUT_SIZE_LARGE)

            return "XLARGE";
        }
    }

}
